|Docs| |Build Status| |Coverage|

.. |Docs| image:: https://readthedocs.org/projects/scanpy/badge/?version=latest
   :target: https://scanpy.readthedocs.io
.. |Build Status| image:: https://travis-ci.org/theislab/anndata.svg?branch=master
   :target: https://travis-ci.org/theislab/anndata
.. |Coverage| image:: https://codecov.io/gh/theislab/anndata/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/theislab/anndata

AnnData
=======

An ``AnnData`` object ``adata`` stores a data matrix (``adata.data``),
dataframe-like sample (``adata.smp``) and variable (``adata.var``) annotation
and unstructured dict-like annotation (``adata.uns``).

Read the `documentation <http://scanpy.readthedocs.io/en/latest/api/scanpy.api.AnnData.html>`_.
